@@ -1,3 +1,3 @@
-from .qa import Qa
+from .tfidf import Qa
 
 __version__ = "1.0"
